Cobalt API
==========

Cobalt has classes for each Akoma Ntoso document type.

Base classes
............

.. automodule:: cobalt.akn
    :members:

Amendment
.........

.. automodule:: cobalt.amendment
    :members:
    :show-inheritance:

Collection
..........

.. automodule:: cobalt.collection
    :members:
    :show-inheritance:

Debate
......

.. automodule:: cobalt.debate
    :members:
    :show-inheritance:

Hierarchical structure
......................

.. automodule:: cobalt.hierarchical
    :members:
    :show-inheritance:

Judgment
........

.. automodule:: cobalt.judgment
    :members:
    :show-inheritance:

Open structure
..............

.. automodule:: cobalt.openstructure
    :members:
    :show-inheritance:

Portion
.......

.. automodule:: cobalt.portion
    :members:
    :show-inheritance:

FRBR URIs
.........

.. automodule:: cobalt.uri

    .. autoclass:: FrbrUri
        :members:

Schemas and validation
......................

.. automodule:: cobalt.schemas

    .. autofunction:: validate
    .. autofunction:: assert_validates
